@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Code::TidyAll::Plugin::SortLines::Naturally;
-$Code::TidyAll::Plugin::SortLines::Naturally::VERSION = '0.000001';
+$Code::TidyAll::Plugin::SortLines::Naturally::VERSION = '0.000002';
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
@@ -16,19 +16,17 @@ sub transform_source {
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
 
 =head1 NAME
 
-Code::TidyAll::Plugin::SortLines::Naturally
+Code::TidyAll::Plugin::SortLines::Naturally - Sort lines of a file using Sort::Naturally
 
 =head1 VERSION
 
-version 0.000001
+version 0.000002
 
 =head1 SYNOPSIS
 
@@ -43,16 +41,10 @@ Sorts the lines of a file; whitespace lines are discarded. Useful for files
 containing one entry per line, such as C<.svnignore>, C<.gitignore>, and
 C<.ispell*>.
 
-=head1 NAME
-
-Code::TidyAll::Plugin::SortLines::Naturally - sort lines of a file using Sort::Naturally
-
 =head1 ACKNOWLEDGEMENTS
 
 This code was essentially pilfered from L<Code::TidyAll::Plugin::SortLines>
 
-1;
-
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
@@ -65,3 +57,8 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+# ABSTRACT: Sort lines of a file using Sort::Naturally
+
